==> kubernetes-model-core-4.12.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/ListOptionsFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface ListOptionsFluent<A extends ListOptionsFluent<A>> extends Fluent<A> {


    public Boolean isAllowWatchBookmarks();
    public A withAllowWatchBookmarks(Boolean allowWatchBookmarks);
    public Boolean hasAllowWatchBookmarks();
    public A withNewAllowWatchBookmarks(String arg1);
    public A withNewAllowWatchBookmarks(boolean arg1);
    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getContinue();
    public A withContinue(String _continue);
    public Boolean hasContinue();
    public A withNewContinue(String arg1);
    public A withNewContinue(StringBuilder arg1);
    public A withNewContinue(StringBuffer arg1);
    public String getFieldSelector();
    public A withFieldSelector(String fieldSelector);
    public Boolean hasFieldSelector();
    public A withNewFieldSelector(String arg1);
    public A withNewFieldSelector(StringBuilder arg1);
    public A withNewFieldSelector(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public String getLabelSelector();
    public A withLabelSelector(String labelSelector);
    public Boolean hasLabelSelector();
    public A withNewLabelSelector(String arg1);
    public A withNewLabelSelector(StringBuilder arg1);
    public A withNewLabelSelector(StringBuffer arg1);
    public Long getLimit();
    public A withLimit(Long limit);
    public Boolean hasLimit();
    public String getResourceVersion();
    public A withResourceVersion(String resourceVersion);
    public Boolean hasResourceVersion();
    public A withNewResourceVersion(String arg1);
    public A withNewResourceVersion(StringBuilder arg1);
    public A withNewResourceVersion(StringBuffer arg1);
    public Long getTimeoutSeconds();
    public A withTimeoutSeconds(Long timeoutSeconds);
    public Boolean hasTimeoutSeconds();
    public Boolean isWatch();
    public A withWatch(Boolean watch);
    public Boolean hasWatch();
    public A withNewWatch(String arg1);
    public A withNewWatch(boolean arg1);
}

==> kubernetes-model-core-5.2.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/ListOptionsFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Long;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;

public interface ListOptionsFluent<A extends ListOptionsFluent<A>> extends Fluent<A> {


    public Boolean isAllowWatchBookmarks();
    public A withAllowWatchBookmarks(Boolean allowWatchBookmarks);
    public Boolean hasAllowWatchBookmarks();
    public A withNewAllowWatchBookmarks(String arg1);
    public A withNewAllowWatchBookmarks(boolean arg1);
    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getContinue();
    public A withContinue(String _continue);
    public Boolean hasContinue();
    public A withNewContinue(String arg1);
    public A withNewContinue(StringBuilder arg1);
    public A withNewContinue(StringBuffer arg1);
    public String getFieldSelector();
    public A withFieldSelector(String fieldSelector);
    public Boolean hasFieldSelector();
    public A withNewFieldSelector(String arg1);
    public A withNewFieldSelector(StringBuilder arg1);
    public A withNewFieldSelector(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public String getLabelSelector();
    public A withLabelSelector(String labelSelector);
    public Boolean hasLabelSelector();
    public A withNewLabelSelector(String arg1);
    public A withNewLabelSelector(StringBuilder arg1);
    public A withNewLabelSelector(StringBuffer arg1);
    public Long getLimit();
    public A withLimit(Long limit);
    public Boolean hasLimit();
    public A withNewLimit(String arg1);
    public A withNewLimit(long arg1);
    public String getResourceVersion();
    public A withResourceVersion(String resourceVersion);
    public Boolean hasResourceVersion();
    public A withNewResourceVersion(String arg1);
    public A withNewResourceVersion(StringBuilder arg1);
    public A withNewResourceVersion(StringBuffer arg1);
    public String getResourceVersionMatch();
    public A withResourceVersionMatch(String resourceVersionMatch);
    public Boolean hasResourceVersionMatch();
    public A withNewResourceVersionMatch(String arg1);
    public A withNewResourceVersionMatch(StringBuilder arg1);
    public A withNewResourceVersionMatch(StringBuffer arg1);
    public Long getTimeoutSeconds();
    public A withTimeoutSeconds(Long timeoutSeconds);
    public Boolean hasTimeoutSeconds();
    public A withNewTimeoutSeconds(String arg1);
    public A withNewTimeoutSeconds(long arg1);
    public Boolean isWatch();
    public A withWatch(Boolean watch);
    public Boolean hasWatch();
    public A withNewWatch(String arg1);
    public A withNewWatch(boolean arg1);
}
